from ocr_table import ocr_table
from auxiliary import Auxiliary

if ocr_table and Auxiliary:
    pass
